@@ -52,6 +52,9 @@ pub struct Endpoint {
     pub laddr: SocketAddr,
     pub raddr: RemoteAddr,
     pub conn_opts: ConnectOpts,
+
+    #[cfg(feature = "multi-remote")]
+    pub extra_raddrs: Vec<RemoteAddr>,
 }
 
 // display impl below
@@ -68,7 +71,19 @@ impl Display for RemoteAddr {
 
 impl Display for Endpoint {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        write!(f, "{} -> {}; options: {}", &self.laddr, &self.raddr, &self.conn_opts)
+        #[cfg(not(feature = "multi-remote"))]
+        write!(f, "{} -> {}; options: {}", &self.laddr, &self.raddr, &self.conn_opts)?;
+
+        #[cfg(feature = "multi-remote")]
+        {
+            write!(f, "{} -> [{}", &self.laddr, &self.raddr)?;
+            for raddr in self.extra_raddrs.iter() {
+                write!(f, "|{}", raddr)?;
+            }
+            write!(f, "]; options: {}", &self.conn_opts)?;
+        }
+
+        Ok(())
     }
 }
 
